(function (ng) {
    /**
     * @ngdoc module
     * @module apeman-ui-contrib-angular-storaging
     * @name apeman-ui-contrib-angular-storaging
     * @description
     * apeman ui module for angular to work with localstorage.
     */

    "use strict";

    ng
        .module('apeman-ui-contrib-angular-storaging', []);

})(angular);
(function (ng, localStorage) {
    /**
     * @ngdoc service
     * @module apeman-ui-contrib-angular-storaging
     * @name apStorage
     * @description
     * Local storage wrapper.
     */

    "use strict";

    ng
        .module('apeman-ui-contrib-angular-storaging')
        .service("apStorage", function () {
            var s = this;

            /**
             * @ngdoc method
             * @name apStorage#get
             * @description Get data with key from local storage.
             * @param {string} key - Key for storage.
             * @returns {object|string|null} - Acquired value.
             */
            s.get = function get(key) {
                var s = this;
                return s.getObj(key) || s.getStr(key) || null;
            };
            /**
             * @ngdoc method
             * @name apStorage#getObj
             * @description Get value as an object.
             * @param {string} key - Key for storage.
             * @returns {object|null} - Acquired value.
             */
            s.getObj = function getObj(key) {
                var s = this,
                    val = s._getItem(key);
                try {
                    return JSON.parse(val);
                } catch (e) {
                    // Ignore error.
                    return null;
                }
            };
            /**
             * @ngdoc method
             * @name apStorage#getStr
             * @description Get value as string.
             * @param {string} key - Key for storage.
             * @returns {string|null} - Acquired value.
             */
            s.getStr = function getStr(key) {
                var s = this,
                    val = s._getItem(key);
                return val && String(val) || null;
            };
            /**
             * @ngdoc method
             * @name apStorage#set
             * @description Set a value to save localstorage.
             * @param {string} key - Key for storage.
             * @param {string|object} val - Value to get.
             */
            s.set = function set(key, val) {
                var s = this;
                switch (typeof val) {
                    case 'object':
                        s.setObj(key, val);
                        break;
                    default:
                        s.setStr(key, val);
                        break;
                }
            };
            /**
             * @ngdoc method
             * @name apStorage#remove
             * @description Remove an item from localstorage.
             * @param {string} key - Key to remove.
             */
            s.remove = function (key) {
                var s = this;
                s._removeItem(key);
            };
            /**
             * @ngdoc method
             * @name apStorage#setObj
             * @description Set an object.
             * @param {string} key - Key for storage.
             * @param {object} obj - Object to set.
             */
            s.setObj = function (key, obj) {
                var s = this;
                try {
                    s._setItem(key, JSON.stringify(obj));
                } catch (e) {
                    s._setItem(key, obj);
                }
            };
            /**
             * @ngdoc method
             * @name apStorage#setStr
             * @description Set string.
             * @param {string} key - Key for storage.
             * @param {string} str - String to save.
             */
            s.setStr = function (key, str) {
                var s = this;
                s._setItem(key, String(str));
            };
            s._getItem = function (key) {
                return localStorage.getItem(key);
            };
            s._setItem = function (key, val) {
                localStorage.setItem(key, val);
            };
            s._removeItem = function (key) {
                localStorage.removeItem(key);
            };
        });
})
(angular, window.localStorage);
